aboutsummaryrefslogtreecommitdiff
path: root/bdep/bdep.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'bdep/bdep.cxx')
-rw-r--r--bdep/bdep.cxx3
1 files changed, 2 insertions, 1 deletions
diff --git a/bdep/bdep.cxx b/bdep/bdep.cxx
index 66431e9..7e6435f 100644
--- a/bdep/bdep.cxx
+++ b/bdep/bdep.cxx
@@ -212,10 +212,11 @@ init (const common_options& co,
: o.V () ? 3 : o.v () ? 2 : o.quiet () ? 0 : 1;
};
// Handle default option files.
//
// Note: don't need to use group_scaner (no arguments in options files).
//
+ if (!o.no_default_options ()) // Command line option.
try
{
o = merge_options (
@@ -212,10 +212,11 @@ init (const common_options& co,
: o.V () ? 3 : o.v () ? 2 : o.quiet () ? 0 : 1;
};
- // Handle default option files.
+ // Handle default options files.
//
// Note: don't need to use group_scaner (no arguments in options files).